@@ -1,5 +1,5 @@
 # -*-Perl-*-
-# $Id: Sybase.pm,v 1.73 2004/09/23 15:32:48 mpeppler Exp $
+# $Id: Sybase.pm,v 1.75 2004/10/04 14:13:32 mpeppler Exp $
 
 # Copyright (c) 1996-2004   Michael Peppler
 #
@@ -25,8 +25,8 @@
 
     $hostname = Sys::Hostname::hostname();
     $init_done = 0;
-    $VERSION = '1.04_9';
-    my $Revision = substr(q$Revision: 1.73 $, 10);
+    $VERSION = '1.04_10';
+    my $Revision = substr(q$Revision: 1.75 $, 10);
 
     require_version DBI 1.30;
 
@@ -109,15 +109,16 @@
 	
 	my $sth = $this->prepare("select \@\@version");
 	if($sth->execute) {
-	    my $row = $sth->fetch;
-	    if($row && ref($row)) {
-		if($row->[0] =~ /microsoft/i) {
-		    $this->{syb_server_version} = -1;
-		    #warn "Connected to MS-SQL\n";
-		} elsif($row->[0] =~ /adaptive server enterprise\/([\d\.]+)/i ||
-		       $row->[0] =~ /sql server\/([\d\.]+)/i) {
-		    $this->{syb_server_version} = $1;
-		    #warn "Connected to Sybase\n";
+	    while(my $row = $sth->fetch) {
+		if($row && ref($row)) {
+		    if($row->[0] =~ /microsoft/i) {
+			$this->{syb_server_version} = -1;
+			#warn "Connected to MS-SQL\n";
+		    } elsif($row->[0] =~ /adaptive server enterprise\/([\d\.]+)/i ||
+			    $row->[0] =~ /sql server\/([\d\.]+)/i) {
+			$this->{syb_server_version} = $1;
+			#warn "Connected to Sybase\n";
+		    }
 		}
 	    }
 	}
@@ -1096,14 +1097,18 @@ Default is for this attribute to be B<0>.
 Setting this attribute causes $sth->execute() to fetch the return status
 of any executed stored procs in the SQL being executed. If the return
 status is non-0 then $sth->execute() will report that the operation 
-failed (ie it will return C<undef>). This will B<NOT> cause an error
-to be raised if RaiseError is set, however. To get that behaviour
-you need to generate a user error code in the stored proc via
-a 
+failed. 
 
-    raiserror <num> <errmsg> 
+B<NOTE> The result status is NOT the first result set that
+is fetched from a stored proc execution. If the procedure includes
+SELECT statements then these will be fetched first, which means that 
+C<$sth->execute> will NOT return a failure in that case as DBD::Sybase
+won't have seen the result status yet at that point.
 
-statement.
+The RaiseError will NOT be triggered by a non-0 return status if 
+there isn't an associated error message either generated by Sybase
+(duplicate insert error, etc) or generated in the procedure via a T-SQL
+C<raiserror> statement.
 
 Setting this attribute does B<NOT> affect existing $sth handles, only
 those that are created after setting it. To change the behavior of 
